@@ -99,8 +99,8 @@ class JsonObject(object):
 
 class Source(JsonObject):
     """
-    A collection / granule / variable data source as found in the Harmony message
-    "sources" list.
+    A collection / granule / variable / coordinateVariable data source as found in
+    the Harmony message "sources" list.
 
     Attributes
     ----------
@@ -108,6 +108,9 @@ class Source(JsonObject):
         The id of the collection the data source's variables and granules are in
     variables : list
         A list of Variable objects for the variables which should be transformed
+    coordinateVariables: list
+        A list of Variable objects containing the coordinate variables for the
+        collection.
     granules : list
         A list of Granule objects for the granules which should be operated on
     """
@@ -124,7 +127,10 @@ class Source(JsonObject):
         super().__init__(message_data,
                          properties=['collection'],
                          list_properties={
-                             'variables': Variable, 'granules': Granule}
+                             'variables': Variable,
+                             'coordinateVariables': Variable,
+                             'granules': Granule
+                            }
                          )
         for granule in self.granules:
             granule.collection = self.collection
@@ -156,11 +162,11 @@ class Variable(JsonObject):
         Parameters
         ----------
         message_data : dictionary
-            The Harmony message "variables" item to deserialize
+            The Harmony message "variables" or "coordinateVariables" item to deserialize
         """
         super().__init__(
             message_data,
-            properties=['id', 'name', 'fullPath'],
+            properties=['id', 'name', 'fullPath', 'type', 'subtype'],
             list_properties={
                 'relatedUrls': RelatedUrl
             })
@@ -266,6 +272,34 @@ class MinMax(JsonObject):
         super().__init__(message_data, properties=['min', 'max'])
 
 
+class Dimension(JsonObject):
+    """
+    Dimension subset parameters as found in a single dimension from the list of the
+    Harmony message's "subset.dimensions" field.
+
+    Attributes
+    ----------
+    name: string
+        The name of the dimension
+    min: float
+        The min value for the dimension
+    max: float
+        The max value for the dimension
+    """
+
+    def __init__(self, message_data):
+        """
+        Constructor
+
+        Parameters
+        ----------
+        message_data : dictionary
+            A single dimension from the list of the Harmony message's "subset.dimensions"
+            field
+        """
+        super().__init__(message_data, properties=['name', 'min', 'max'])
+
+
 class ScaleExtent(JsonObject):
     """
     Scale extent parameters as found in a Harmony message's "format.scaleExtent" object
@@ -436,6 +470,11 @@ class Subset(JsonObject):
     bbox : list
         A list of 4 floating point values corresponding to [West, South, East, North]
         coordinates
+    point: list containing 2 floating point values corresponding to longitude and latitude
+    shape: RemoteResource
+        A reference to a location containing a shapefile
+    dimensions: list
+        A list of Dimension objects to subset against
     """
 
     def __init__(self, message_data):
@@ -447,9 +486,14 @@ class Subset(JsonObject):
         message_data : dictionary
             The Harmony message "subset" object to deserialize
         """
-        super().__init__(message_data, properties=['bbox', 'point', 'shape'])
+        super().__init__(message_data, properties=['bbox', 'point', 'shape', 'dimensions'])
         if self.shape is not None:
             self.shape = RemoteResource(message_data['shape'])
+        if self.dimensions is not None:
+            dimensions = []
+            for dimension in self.dimensions:
+                dimensions.append(Dimension(dimension))
+            self.dimensions = dimensions
 
 
 class Temporal(JsonObject):
